==> haskell-generic-lens-lite-0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens-lite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-lens-lite
version:              0.1
visibility:           public
id:                   generic-lens-lite-0.1-6c9NdqTQFs5HTRkDu8fyHv
key:                  generic-lens-lite-0.1-6c9NdqTQFs5HTRkDu8fyHv
license:              BSD-3-Clause
copyright:            Copyright (c) 2019 Edward Kmett, 2020 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett, Csongor Kiss, Oleg Grenrus
homepage:             https://github.com/phadej/generic-lens-lite
synopsis:             Monomorphic field lens like with generic-lens
description:
    Derivation of (monomorphic, i.e. not type-changing) lens, like generic-lens.

    The package have minimal dependecies and minimal API:

    @
    class HasField (name :: Symbol) r a | name r -> a
    field :: HasField name r a => Lens'\'' r a
    @

category:             Lens, Generics
abi:                  fb01883c9f2d1246b2dc96fb991c714d
exposed:              True
exposed-modules:      Data.Generics.Lens.Lite
hidden-modules:       Data.Functor.Confusing
import-dirs:          /usr/lib/ghc-8.10.4/site-local/generic-lens-lite-0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/generic-lens-lite-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/generic-lens-lite-0.1
hs-libraries:         HSgeneric-lens-lite-0.1-6c9NdqTQFs5HTRkDu8fyHv
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-generic-lens-lite/html/generic-lens-lite.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens-lite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-lens-lite-0.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens-lite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-lens-lite
version:              0.1
visibility:           public
id:                   generic-lens-lite-0.1-pOYK5JslTVFaCj4MOLD0j
key:                  generic-lens-lite-0.1-pOYK5JslTVFaCj4MOLD0j
license:              BSD-3-Clause
copyright:            Copyright (c) 2019 Edward Kmett, 2020 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett, Csongor Kiss, Oleg Grenrus
homepage:             https://github.com/phadej/generic-lens-lite
synopsis:             Monomorphic field lens like with generic-lens
description:
    Derivation of (monomorphic, i.e. not type-changing) lens, like generic-lens.

    The package have minimal dependecies and minimal API:

    @
    class HasField (name :: Symbol) r a | name r -> a
    field :: HasField name r a => Lens'\'' r a
    @

category:             Lens, Generics
abi:                  8adf93f9b6419d53f710ddfe41bdf744
exposed:              True
exposed-modules:      Data.Generics.Lens.Lite
hidden-modules:       Data.Functor.Confusing
import-dirs:          /usr/lib/ghc-8.10.5/site-local/generic-lens-lite-0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/generic-lens-lite-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/generic-lens-lite-0.1
hs-libraries:         HSgeneric-lens-lite-0.1-pOYK5JslTVFaCj4MOLD0j
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-generic-lens-lite/html/generic-lens-lite.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens-lite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
